@@ -2,18 +2,17 @@
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
+ * The ASF licenses this file to you under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ * http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
- *
  */
 
 package org.apache.jmeter.samplers;
@@ -584,7 +583,9 @@ public class SampleResult implements Serializable, Cloneable, Searchable {
      */
     public String getSampleLabel(boolean includeGroup) {
         if (includeGroup) {
-            return threadName.substring(0, threadName.lastIndexOf(' ')) + ":" + label;
+            // while JMeters own samplers always set the threadName, that might not be the case for plugins
+            int lastSpacePos = Math.max(0, threadName.lastIndexOf(' '));
+            return threadName.substring(0, lastSpacePos) + ":" + label;
         }
         return label;
     }
@@ -758,7 +759,7 @@ public class SampleResult implements Serializable, Cloneable, Searchable {
         try {
             responseData = response.getBytes(getDataEncodingWithDefault());
         } catch (UnsupportedEncodingException e) {
-            log.warn("Could not convert string, using default encoding. "+e.getLocalizedMessage());
+            log.warn("Could not convert string, using default encoding. {}", e.getLocalizedMessage());
             responseData = response.getBytes(Charset.defaultCharset()); // N.B. default charset is used deliberately here
         }
     }
@@ -777,8 +778,8 @@ public class SampleResult implements Serializable, Cloneable, Searchable {
             responseData = response.getBytes(encodeUsing);
             setDataEncoding(encodeUsing);
         } catch (UnsupportedEncodingException e) {
-            log.warn("Could not convert string using '"+encodeUsing+
-                    "', using default encoding: "+DEFAULT_CHARSET,e);
+            log.warn("Could not convert string using '{}', using default encoding: {}", encodeUsing, DEFAULT_CHARSET,
+                    e);
             responseData = response.getBytes(Charset.defaultCharset()); // N.B. default charset is used deliberately here
             setDataEncoding(DEFAULT_CHARSET);
         }
@@ -810,7 +811,7 @@ public class SampleResult implements Serializable, Cloneable, Searchable {
             }
             return responseDataAsString;
         } catch (UnsupportedEncodingException e) {
-            log.warn("Using platform default as "+getDataEncodingWithDefault()+" caused "+e);
+            log.warn("Using platform default as {} caused {}", getDataEncodingWithDefault(), e.getLocalizedMessage());
             return new String(responseData,Charset.defaultCharset()); // N.B. default charset is used deliberately here
         }
     }
